pub type ServerHookMap = HashMapXxHash3_64<String, ServerHookHandler>;Expand description
Type alias for a map of server route handlers.
Used for fast lookup of exact-match routes.
Aliased Type
pub struct ServerHookMap { /* private fields */ }pub type ServerHookMap = HashMapXxHash3_64<String, ServerHookHandler>;Type alias for a map of server route handlers.
Used for fast lookup of exact-match routes.
pub struct ServerHookMap { /* private fields */ }