pub type FutureBox<T> = Pin<Box<dyn Future<Output = T> + Send>>;Expand description
A type alias for a boxed future with a generic output that can be sent across threads.
This is often used to represent an asynchronous task that can be sent across threads.
Aliased Type
pub struct FutureBox<T> { /* private fields */ }