pub type HookHandler<T> = Arc<dyn FnContextPinBox<T, Output = Pin<Box<dyn Future<Output = T> + Send>>>>;Expand description
A type alias for a shared hook handler.
This type is used for storing handlers in a shared context, allowing multiple parts of the application to safely access and execute the same handler.
Aliased Type
pub struct HookHandler<T> { /* private fields */ }