pub type RouteParams = HashMap<String, String, BuildHasherDefault<Hasher>>;Expand description
A type alias for a hash map that stores captured route parameters.
The key is the parameter name and the value is the captured string.
Aliased Type
pub struct RouteParams { /* private fields */ }